ChannelRef

Struct ChannelRef 

pub struct ChannelRef<'a> { /* private fields */ }
Represents an immutable reference to a channel in an MDF file.

Implementations

Source

impl<'a> ChannelRef<'a>

pub fn as_ptr(&self) -> *const IChannel

Gets the raw pointer to the underlying IChannel. This is used for advanced operations like creating channel observers.

pub fn get_index(&self) -> u64

Gets the index of the channel.

pub fn get_name(&self) -> String

Gets the name of the channel.

pub fn get_display_name(&self) -> String

Gets the display name of the channel.

pub fn get_description(&self) -> String

Gets the description of the channel.

pub fn get_unit(&self) -> String

Gets the unit of the channel.

pub fn get_type(&self) -> u8

Gets the type of the channel.

pub fn get_data_type(&self) -> u8

Gets the data type of the channel.

pub fn get_data_bytes(&self) -> u64

Gets the data bytes of the channel.

pub fn get_metadata(&self) -> Option<MetaDataRef<'_>>

Gets the metadata of the channel.

pub fn get_source_information(&self) -> Option<SourceInformationRef<'_>>

Gets the source information of the channel.

pub fn get_channel_conversion(&self) -> Option<ChannelConversionRef<'_>>

Gets the channel conversion of the channel.

pub fn get_channel_array(&self) -> Option<ChannelArrayRef<'_>>

Gets the channel array of the channel.