pub extern "C" fn log_callback(
severity: MdfLogSeverity,
text: *const u8,
)Expand description
A C-compatible logging callback function that logs messages using the log crate.
pub extern "C" fn log_callback(
severity: MdfLogSeverity,
text: *const u8,
)A C-compatible logging callback function that logs messages using the log crate.