MdfReader

Struct MdfReader 

pub struct MdfReader { /* private fields */ }
Safe wrapper around mdflib’s MdfReader

Implementations

Source

impl MdfReader

pub fn new<P: AsRef<Path>>(path: P) -> Result<Self>

Create a new MDF reader for the specified file

pub fn is_ok(&self) -> bool

Check if the reader is in a valid state

pub fn is_finalized(&self) -> bool

Check if the reader is finialized

pub fn open(&mut self) -> Result<()>

Open the MDF file for reading

pub fn close(&mut self)

Close the MDF file

pub fn get_file(&self) -> Option<MdfFileRef>

Gets the file object.

pub fn read_header(&mut self) -> Result<()>

Read the file header

pub fn read_measurement_info(&mut self) -> Result<()>

Read measurement information

pub fn get_header(&self) -> Option<MdfHeaderRef>

Gets the header from the file.

pub fn read_everything_but_data(&mut self) -> Result<()>

Read everything except data

pub fn get_data_group_count(&self) -> usize

Gets the number of data groups in the file.

pub fn get_data_group(&self, index: usize) -> Option<DataGroupRef>

Gets a data group by its index.

pub fn read_data(&mut self, group: &mut DataGroup) -> Result<()>

Read data from a data group