pub struct ChannelRef<'a> { /* private fields */ }Expand description
Represents an immutable reference to a channel in an MDF file.
Implementations
Sourceimpl<'a> ChannelRef<'a>
impl<'a> ChannelRef<'a>
Sourcepub fn as_ptr(&self) -> *const IChannel
pub fn as_ptr(&self) -> *const IChannel
Gets the raw pointer to the underlying IChannel. This is used for advanced operations like creating channel observers.
Sourcepub fn get_display_name(&self) -> String
pub fn get_display_name(&self) -> String
Gets the display name of the channel.
Sourcepub fn get_description(&self) -> String
pub fn get_description(&self) -> String
Gets the description of the channel.
Sourcepub fn get_data_type(&self) -> u8
pub fn get_data_type(&self) -> u8
Gets the data type of the channel.
Sourcepub fn get_data_bytes(&self) -> u64
pub fn get_data_bytes(&self) -> u64
Gets the data bytes of the channel.
Sourcepub fn get_metadata(&self) -> Option<MetaDataRef<'_>>
pub fn get_metadata(&self) -> Option<MetaDataRef<'_>>
Gets the metadata of the channel.
Sourcepub fn get_source_information(&self) -> Option<SourceInformationRef<'_>>
pub fn get_source_information(&self) -> Option<SourceInformationRef<'_>>
Gets the source information of the channel.
Sourcepub fn get_channel_conversion(&self) -> Option<ChannelConversionRef<'_>>
pub fn get_channel_conversion(&self) -> Option<ChannelConversionRef<'_>>
Gets the channel conversion of the channel.
Sourcepub fn get_channel_array(&self) -> Option<ChannelArrayRef<'_>>
pub fn get_channel_array(&self) -> Option<ChannelArrayRef<'_>>
Gets the channel array of the channel.